@@ -33,7 +33,7 @@ from xml.dom import minidom
 import hashlib
 import os
 
-HOST = 'http://flickr.com'
+HOST = 'https://flickr.com'
 API = '/services/rest'
 
 # set these here or using flickr.API_KEY in your application
